@@ -6,9 +6,10 @@ use strict;
 use warnings 'all';
 
 package BZ::Client;
-$BZ::Client::VERSION = '2.0_11'; # TRIAL
+$BZ::Client::VERSION = '2.0_12'; # TRIAL
 
-$BZ::Client::VERSION = '2.011';use BZ::Client::XMLRPC;
+$BZ::Client::VERSION = '2.012';
+use BZ::Client::XMLRPC;
 use BZ::Client::Exception;
 use HTTP::CookieJar;
 
@@ -270,7 +271,7 @@ BZ::Client - A client for the Bugzilla web services API.
 
 =head1 VERSION
 
-version 2.0_11
+version 2.0_12
 
 =head1 SYNOPSIS
 
@@ -520,7 +521,7 @@ Jochen Wiedmann <jochen.wiedmann@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Dean Hamstad.
+This software is copyright (c) 2016 by Dean Hamstad.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
