@@ -6,9 +6,10 @@ use strict;
 use warnings 'all';
 
 package BZ::Client::API;
-$BZ::Client::API::VERSION = '2.0_11'; # TRIAL
+$BZ::Client::API::VERSION = '2.0_12'; # TRIAL
 
-$BZ::Client::API::VERSION = '2.011';sub api_call {
+$BZ::Client::API::VERSION = '2.012';
+sub api_call {
     my(undef, $client, $methodName, $params) = @_;
     return $client->api_call($methodName, $params)
 }
@@ -70,7 +71,7 @@ BZ::Client::API - Abstract base class for the clients of the Bugzilla API.
 
 =head1 VERSION
 
-version 2.0_11
+version 2.0_12
 
 =head1 SYNOPSIS
 
@@ -121,7 +122,7 @@ Jochen Wiedmann <jochen.wiedmann@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Dean Hamstad.
+This software is copyright (c) 2016 by Dean Hamstad.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
