@@ -6,9 +6,10 @@ use strict;
 use warnings 'all';
 
 package BZ::Client::Bugzilla;
-$BZ::Client::Bugzilla::VERSION = '2.0_11'; # TRIAL
+$BZ::Client::Bugzilla::VERSION = '2.0_12'; # TRIAL
 
-$BZ::Client::Bugzilla::VERSION = '2.011';use parent qw( BZ::Client::API );
+$BZ::Client::Bugzilla::VERSION = '2.012';
+use parent qw( BZ::Client::API );
 
 ## functions
 
@@ -96,7 +97,7 @@ BZ::Client::Bugzilla - Information about the Bugzilla server, i.e. the Bugzilla:
 
 =head1 VERSION
 
-version 2.0_11
+version 2.0_12
 
 =head1 SYNOPSIS
 
@@ -289,7 +290,7 @@ Jochen Wiedmann <jochen.wiedmann@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Dean Hamstad.
+This software is copyright (c) 2016 by Dean Hamstad.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
