@@ -6,9 +6,10 @@ use strict;
 use warnings 'all';
 
 package BZ::Client::Exception;
-$BZ::Client::Exception::VERSION = '2.0_11'; # TRIAL
+$BZ::Client::Exception::VERSION = '2.0_12'; # TRIAL
 
-$BZ::Client::Exception::VERSION = '2.011';sub throw {
+$BZ::Client::Exception::VERSION = '2.012';
+sub throw {
     my $class = shift;
     die $class->new(@_)
 }
@@ -49,7 +50,7 @@ BZ::Client::Exception - Exception class thrown by BZ::Client in case of errors.
 
 =head1 VERSION
 
-version 2.0_11
+version 2.0_12
 
 =head1 SYNOPSIS
 
@@ -151,7 +152,7 @@ Jochen Wiedmann <jochen.wiedmann@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Dean Hamstad.
+This software is copyright (c) 2016 by Dean Hamstad.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
