@@ -1,14 +1,16 @@
 #!/bin/false
 # PODNAME: BZ::Client::Product
 # ABSTRACT: Client side representation of a product in Bugzilla
+# vim: softtabstop=4 tabstop=4 shiftwidth=4 ft=perl expandtab smarttab
 
 use strict;
 use warnings 'all';
 
 package BZ::Client::Product;
-$BZ::Client::Product::VERSION = '2.0_11'; # TRIAL
+$BZ::Client::Product::VERSION = '2.0_12'; # TRIAL
 
-$BZ::Client::Product::VERSION = '2.011';use parent qw( BZ::Client::API );
+$BZ::Client::Product::VERSION = '2.012';
+use parent qw( BZ::Client::API );
 
 # See https://www.bugzilla.org/docs/tip/en/html/api/Bugzilla/WebService/Product.html
 
@@ -61,19 +63,19 @@ sub get_accessible_products {
 
 # do everything in one place
 sub _get {
-    my ($class, $client, $result) = @_;
+    my($class, $client, $result) = @_;
     my $products = $result->{'products'};
-    if (!$products || 'ARRAY' ne ref($products)) {
+    if (!$products or 'ARRAY' ne ref $products) {
         $class->error($client, 'Invalid reply by server, expected array of products.');
     }
     my @result;
     for my $product (@$products) {
-        push(@result, $class->new(
+        push @result, $class->new(
                 id          => $product->{'id'},
                 name        => $product->{'name'},
                 description => $product->{'description'},
-                internals   => $product->{'internals'})
-            );
+                internals   => $product->{'internals'}
+        );
     }
     return wantarray ? @result : \@result
 }
@@ -96,7 +98,8 @@ sub name {
     my $self = shift;
     if (@_) {
         $self->{'name'} = shift;
-    } else {
+    }
+    else {
         return $self->{name};
     }
 }
@@ -105,7 +108,8 @@ sub description {
     my $self = shift;
     if (@_) {
         $self->{'description'} = shift;
-    } else {
+    }
+    else {
         return $self->{'description'};
     }
 }
@@ -114,7 +118,8 @@ sub version {
     my $self = shift;
     if (@_) {
         $self->{'version'} = shift;
-    } else {
+    }
+    else {
         return $self->{'version'};
     }
 }
@@ -124,7 +129,8 @@ sub has_unconfirmed {
     my $self = shift;
     if (@_) {
         $self->{'has_unconfirmed'} = shift;
-    } else {
+    }
+    else {
         return $self->{'has_unconfirmed'};
     }
 }
@@ -133,7 +139,8 @@ sub classification {
     my $self = shift;
     if (@_) {
         $self->{'classification'} = shift;
-    } else {
+    }
+    else {
         return $self->{'classification'};
     }
 }
@@ -142,7 +149,8 @@ sub default_milestone {
     my $self = shift;
     if (@_) {
         $self->{'default_milestone'} = shift;
-    } else {
+    }
+    else {
         return $self->{'default_milestone'};
     }
 }
@@ -152,7 +160,8 @@ sub is_open {
     my $self = shift;
     if (@_) {
         $self->{'is_open'} = shift;
-    } else {
+    }
+    else {
         return $self->{'is_open'};
     }
 }
@@ -161,7 +170,8 @@ sub create_series {
     my $self = shift;
     if (@_) {
         $self->{'create_series'} = shift;
-    } else {
+    }
+    else {
         return $self->{'create_series'};
     }
 }
@@ -212,7 +222,7 @@ BZ::Client::Product - Client side representation of a product in Bugzilla
 
 =head1 VERSION
 
-version 2.0_11
+version 2.0_12
 
 =head1 SYNOPSIS
 
@@ -798,7 +808,7 @@ Jochen Wiedmann <jochen.wiedmann@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Dean Hamstad.
+This software is copyright (c) 2016 by Dean Hamstad.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
