@@ -6,9 +6,10 @@ use strict;
 use warnings 'all';
 
 package BZ::Client::User;
-$BZ::Client::User::VERSION = '2.0_11'; # TRIAL
+$BZ::Client::User::VERSION = '2.0_12'; # TRIAL
 
-$BZ::Client::User::VERSION = '2.011';use parent qw( BZ::Client::API );
+$BZ::Client::User::VERSION = '2.012';
+use parent qw( BZ::Client::API );
 
 # See https://www.bugzilla.org/docs/tip/en/html/api/Bugzilla/WebService/User.html
 
@@ -82,7 +83,7 @@ BZ::Client::User - Creates and edits user accounts in Bugzilla
 
 =head1 VERSION
 
-version 2.0_11
+version 2.0_12
 
 =head1 SYNOPSIS
 
@@ -494,7 +495,7 @@ Jochen Wiedmann <jochen.wiedmann@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Dean Hamstad.
+This software is copyright (c) 2016 by Dean Hamstad.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
