@@ -6,9 +6,10 @@ use strict;
 use warnings 'all';
 
 package BZ::Client::XMLRPC;
-$BZ::Client::XMLRPC::VERSION = '2.0_11'; # TRIAL
+$BZ::Client::XMLRPC::VERSION = '2.0_12'; # TRIAL
 
-$BZ::Client::XMLRPC::VERSION = '2.011';use URI;
+$BZ::Client::XMLRPC::VERSION = '2.012';
+use URI;
 use Encode;
 use XML::Writer;
 use HTTP::Tiny;
@@ -318,17 +319,17 @@ sub logDirectory {
 }
 
 package BZ::Client::XMLRPC::int;
-$BZ::Client::XMLRPC::int::VERSION = '2.0_11'; # TRIAL
+$BZ::Client::XMLRPC::int::VERSION = '2.0_12'; # TRIAL
 
-$BZ::Client::XMLRPC::int::VERSION = '2.011';sub new {
+$BZ::Client::XMLRPC::int::VERSION = '2.012';sub new {
     my($class, $value) = @_;
     return bless(\$value, (ref($class) || $class))
 }
 
 package BZ::Client::XMLRPC::boolean;
-$BZ::Client::XMLRPC::boolean::VERSION = '2.0_11'; # TRIAL
+$BZ::Client::XMLRPC::boolean::VERSION = '2.0_12'; # TRIAL
 
-$BZ::Client::XMLRPC::boolean::VERSION = '2.011';sub new {
+$BZ::Client::XMLRPC::boolean::VERSION = '2.012';sub new {
     my($class, $value) = @_;
     return bless(\$value, (ref($class) || $class))
 }
@@ -344,9 +345,9 @@ sub FALSE { $false }
 }
 
 package BZ::Client::XMLRPC::double;
-$BZ::Client::XMLRPC::double::VERSION = '2.0_11'; # TRIAL
+$BZ::Client::XMLRPC::double::VERSION = '2.0_12'; # TRIAL
 
-$BZ::Client::XMLRPC::double::VERSION = '2.011';sub new {
+$BZ::Client::XMLRPC::double::VERSION = '2.012';sub new {
     my($class, $value) = @_;
     return bless(\$value, (ref($class) || $class))
 }
@@ -365,7 +366,7 @@ BZ::Client::XMLRPC - Performs XML-RPC calls on behalf of the client.
 
 =head1 VERSION
 
-version 2.0_11
+version 2.0_12
 
 =head1 SYNOPSIS
 
@@ -427,7 +428,7 @@ Jochen Wiedmann <jochen.wiedmann@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Dean Hamstad.
+This software is copyright (c) 2016 by Dean Hamstad.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
